@@ -9,7 +9,7 @@ use Apache::Session::Lock::Null;
 use Apache::Session::Serialize::JSON;
 use Apache::Session::Browseable::_common;
 
-our $VERSION = '1.3.2';
+our $VERSION = '1.3.4';
 our @ISA     = qw(Apache::Session);
 
 our $redis = $Apache::Session::Browseable::Store::Redis::redis;
@@ -43,17 +43,23 @@ sub searchOn {
     if ( grep { $_ eq $selectField } @$index ) {
 
         my $redisObj = $class->_getRedis($args);
-        my @keys = $redisObj->smembers("${selectField}_$value");
+        my @keys     = $redisObj->smembers("${selectField}_$value");
         foreach my $k (@keys) {
             next unless ($k);
             my $tmp = $redisObj->get($k);
             next unless ($tmp);
-            $tmp = unserialize($tmp);
-            if (@fields) {
-                $res{$k}->{$_} = $tmp->{$_} foreach (@fields);
-            }
-            else {
-                $res{$k} = $tmp;
+            eval {
+                $tmp = unserialize($tmp);
+                if (@fields) {
+                    $res{$k}->{$_} = $tmp->{$_} foreach (@fields);
+                }
+                else {
+                    $res{$k} = $tmp;
+                }
+            };
+            if ($@) {
+                print STDERR "Error in session $k: $@\n";
+                delete $res{$k};
             }
         }
     }
@@ -86,21 +92,27 @@ sub get_key_from_all_sessions {
     my %res;
 
     my $redisObj = $class->_getRedis($args);
-    my @keys = $redisObj->keys('*');
+    my @keys     = $redisObj->keys('*');
     foreach my $k (@keys) {
         next if ( !$k or $k =~ /_/ );
-        my $v   = $redisObj->get($k);
-        my $tmp = unserialize($v);
-        if ( ref($data) eq 'CODE' ) {
-            $tmp = &$data( $tmp, $k );
-            $res{$k} = $tmp if ( defined($tmp) );
-        }
-        elsif ($data) {
-            $data = [$data] unless ( ref($data) );
-            $res{$k}->{$_} = $tmp->{$_} foreach (@$data);
-        }
-        else {
-            $res{$k} = $tmp;
+        eval {
+            my $v   = $redisObj->get($k);
+            my $tmp = unserialize($v);
+            if ( ref($data) eq 'CODE' ) {
+                $tmp = &$data( $tmp, $k );
+                $res{$k} = $tmp if ( defined($tmp) );
+            }
+            elsif ($data) {
+                $data = [$data] unless ( ref($data) );
+                $res{$k}->{$_} = $tmp->{$_} foreach (@$data);
+            }
+            else {
+                $res{$k} = $tmp;
+            }
+        };
+        if ($@) {
+            print STDERR "Error in session $k: $@\n";
+            delete $res{$k};
         }
     }
     return \%res;
